==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/es_es/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.!success.department_created'] = 'El departamento %1$s se ha creado correctamente.';
$lang['AdminDepartments.!success.department_updated'] = 'El departamento %1$s se ha actualizado correctamente.';
$lang['AdminDepartments.!success.department_deleted'] = 'El departamento %1$s se ha eliminado correctamente.';
$lang['AdminDepartments.index.page_title'] = 'Gestor de asistencia > Departamentos';
$lang['AdminDepartments.add.page_title'] = 'Gestor de Soporte > Departamentos > Añadir Departamento';
$lang['AdminDepartments.edit.page_title'] = 'Gestor de Soporte > Departamentos > Editar Departamento';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Añadir departamento';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departamentos';
$lang['AdminDepartments.index.heading_name'] = 'Nombre';
$lang['AdminDepartments.index.heading_description'] = 'Descripción';
$lang['AdminDepartments.index.heading_email'] = 'Correo electrónico';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Personal asignado';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.index.heading_options'] = 'Opciones';
$lang['AdminDepartments.index.option_edit'] = 'Editar';
$lang['AdminDepartments.index.option_delete'] = 'Borrar';
$lang['AdminDepartments.index.confirm_delete'] = 'Los departamentos con tickets asignados no se pueden eliminar hasta que todos los tickets se hayan reasignado a un departamento alternativo. ¿Está seguro de que desea eliminar este departamento?';
$lang['AdminDepartments.index.no_results'] = 'No hay departamentos.';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Personal asignado';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personal';
$lang['AdminDepartments.assigned_staff.no_results'] = 'No hay personal asignado a este departamento.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Establezca la ruta de pipe como se muestra, pero asegúrese de utilizar la ruta correcta a PHP en su servidor. Asegúrese de que pipe.php es ejecutable. También puede ser necesario editar pipe.php para incluir un hashbang en la línea 1 que se vería algo como: #!/usr/bin/php';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Todos los tickets con un estado distinto de %1$s cuya última respuesta sea de un miembro del personal se cerrarán automáticamente si no se ha producido ninguna respuesta en el periodo de tiempo seleccionado.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Todos los tickets con un estado de %1$s se eliminarán automáticamente después de permanecer en ese estado durante el tiempo seleccionado.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Para todas las entradas con un estado distinto de %1$s, se enviará un recordatorio a la otra parte si no se ha respondido en el plazo seleccionado.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Al desmarcar esta casilla se indica que los nuevos tickets creados para este departamento (por correo electrónico o cliente) no enviarán un aviso de respuesta al cliente o al personal a través del correo electrónico Ticket Recibido o el correo electrónico Ticket Actualizado del Personal, respectivamente.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Cambia el estado a %1$s cuando responde un miembro del personal.';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Los servidores de correo tienen limitaciones en cuanto al tamaño de los archivos adjuntos y los tipos de archivo. Para mitigar el riesgo de que el correo electrónico sea rechazado, incluya las limitaciones de tipo y tamaño de los archivos adjuntos. Para asegurarse de que el cliente conoce los archivos adjuntos que no se han incluido, utilice la etiqueta {ticket.reply_has_attachments} en las notificaciones de los tickets.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista de extensiones admitidas separadas por comas (por ejemplo, zip,jpg,png).';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Tamaño máximo del adjunto a incluir en MB.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Si el cliente puede o no enviar el campo, si es false el cliente solo podrá leer el campo.';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Si se cierra el ticket, los datos del campo se borrarán automáticamente. Los datos dejarán de ser visibles para el personal.';
$lang['AdminDepartments.!text.add_response'] = 'Establecer una respuesta predefinida de cierre automático';
$lang['AdminDepartments.!text.no_selected_response'] = 'No se ha seleccionado la respuesta de cierre automático.';
$lang['AdminDepartments.!text.remove_response'] = 'Eliminar';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Añadir departamento';
$lang['AdminDepartments.add.tab_general'] = 'General';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.add.field_name'] = 'Nombre';
$lang['AdminDepartments.add.field_description'] = 'Descripción';
$lang['AdminDepartments.add.field_clients_only'] = 'Permitir sólo a los clientes abrir o responder tickets';
$lang['AdminDepartments.add.field_require_captcha'] = 'Requerir verificación humana para usuarios no autenticados';
$lang['AdminDepartments.add.field_email'] = 'Correo electrónico';
$lang['AdminDepartments.add.field_override_from_email'] = 'Sustituya la dirección de remitente establecida en las plantillas de correo electrónico por la dirección de correo electrónico establecida para este departamento.';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Enviar correos electrónicos de respuesta automática para nuevos tickets';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Transición automática del estado del ticket al responder el administrador';
$lang['AdminDepartments.add.field_method'] = 'Gestión del correo electrónico';
$lang['AdminDepartments.add.field_piping_config'] = 'Configuración de tuberías';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.add.field_include_attachments'] = 'Incluir archivos adjuntos compatibles en las notificaciones de tickets';
$lang['AdminDepartments.add.field_attachment_types'] = 'Tipos de archivos adjuntos admitidos';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Tamaño máximo del accesorio';
$lang['AdminDepartments.add.field_security'] = 'Seguridad';
$lang['AdminDepartments.add.field_box_name'] = 'Nombre de la caja';
$lang['AdminDepartments.add.field_mark_messages'] = 'Marcar mensajes como';
$lang['AdminDepartments.add.field_host'] = 'Anfitrión';
$lang['AdminDepartments.add.field_user'] = 'Usuario';
$lang['AdminDepartments.add.field_pass'] = 'Pase';
$lang['AdminDepartments.add.field_port'] = 'Puerto';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Cerrar tickets automáticamente';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Borrar tickets automáticamente';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Envío automático de recordatorios de entradas';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Enviar recordatorios a los tickets con estado';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Enviar recordatorios a los tickets con prioridad';
$lang['AdminDepartments.add.field_response_id'] = 'Auto-cerrar Ticket Respuesta';
$lang['AdminDepartments.add.field_status'] = 'Estado';
$lang['AdminDepartments.add.field_addsubmit'] = 'Añadir departamento';
$lang['AdminDepartments.add.field_add_field'] = 'Añadir campo';
$lang['AdminDepartments.add.heading_label'] = 'Etiqueta';
$lang['AdminDepartments.add.heading_description'] = 'Descripción';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilidad';
$lang['AdminDepartments.add.heading_type'] = 'Tipo';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_step'] = 'Paso';
$lang['AdminDepartments.add.heading_client_add'] = 'El cliente puede Añadir';
$lang['AdminDepartments.add.heading_encrypted'] = 'Cifrado';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Borrado automático';
$lang['AdminDepartments.add.heading_options'] = 'Opciones';
$lang['AdminDepartments.add.heading_name'] = 'Nombre';
$lang['AdminDepartments.add.heading_value'] = 'Valor';
$lang['AdminDepartments.add.heading_default'] = 'Por defecto';
$lang['AdminDepartments.add.text_delete'] = 'Borrar';
$lang['AdminDepartments.add.text_add'] = 'Añadir';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Editar Departamento';
$lang['AdminDepartments.edit.tab_general'] = 'General';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.edit.field_name'] = 'Nombre';
$lang['AdminDepartments.edit.field_description'] = 'Descripción';
$lang['AdminDepartments.edit.field_clients_only'] = 'Permitir sólo a los clientes abrir o responder tickets';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Requerir verificación humana para usuarios no autenticados';
$lang['AdminDepartments.edit.field_email'] = 'Correo electrónico';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Sustituya la dirección de remitente establecida en las plantillas de correo electrónico por la dirección de correo electrónico establecida para este departamento.';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Enviar correos electrónicos de respuesta automática para nuevos tickets';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Transición automática del estado del ticket al responder el administrador';
$lang['AdminDepartments.edit.field_method'] = 'Gestión del correo electrónico';
$lang['AdminDepartments.edit.field_piping_config'] = 'Configuración de tuberías';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Incluir archivos adjuntos compatibles en las notificaciones de tickets';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Tipos de archivos adjuntos admitidos';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Tamaño máximo del accesorio';
$lang['AdminDepartments.edit.field_security'] = 'Seguridad';
$lang['AdminDepartments.edit.field_box_name'] = 'Nombre de la caja';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Marcar mensajes como';
$lang['AdminDepartments.edit.field_host'] = 'Anfitrión';
$lang['AdminDepartments.edit.field_user'] = 'Usuario';
$lang['AdminDepartments.edit.field_pass'] = 'Pase';
$lang['AdminDepartments.edit.field_port'] = 'Puerto';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Cerrar tickets automáticamente';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Borrar tickets automáticamente';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Envío automático de recordatorios de entradas';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Enviar recordatorios a los tickets con estado';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Enviar recordatorios a los tickets con prioridad';
$lang['AdminDepartments.edit.field_response_id'] = 'Auto-cerrar Ticket Respuesta';
$lang['AdminDepartments.edit.field_status'] = 'Estado';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Editar Departamento';
$lang['AdminDepartments.edit.field_add_field'] = 'Añadir campo';
$lang['AdminDepartments.edit.confirm_field_remove'] = '¿Está seguro de que desea eliminar este campo personalizado? Se eliminarán todos los datos asociados a este campo. Si desea ocultar este campo y conservar los datos, cambie su Visibilidad a Solo personal.';
$lang['AdminDepartments.edit.no_results'] = 'No hay campos personalizados en este departamento.';
$lang['AdminDepartments.edit.heading_label'] = 'Etiqueta';
$lang['AdminDepartments.edit.heading_description'] = 'Descripción';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilidad';
$lang['AdminDepartments.edit.heading_type'] = 'Tipo';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_step'] = 'Paso';
$lang['AdminDepartments.edit.heading_client_add'] = 'El cliente puede Añadir';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Cifrado';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Borrado automático';
$lang['AdminDepartments.edit.heading_options'] = 'Opciones';
$lang['AdminDepartments.edit.heading_name'] = 'Nombre';
$lang['AdminDepartments.edit.heading_value'] = 'Valor';
$lang['AdminDepartments.edit.heading_default'] = 'Por defecto';
$lang['AdminDepartments.edit.text_delete'] = 'Borrar';
$lang['AdminDepartments.edit.text_add'] = 'Añadir';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/es_es/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.!success.department_created'] = 'El departamento %1$s se ha creado correctamente.';
$lang['AdminDepartments.!success.department_updated'] = 'El departamento %1$s se ha actualizado correctamente.';
$lang['AdminDepartments.!success.department_deleted'] = 'El departamento %1$s se ha eliminado correctamente.';
$lang['AdminDepartments.index.page_title'] = 'Gestor de asistencia > Departamentos';
$lang['AdminDepartments.add.page_title'] = 'Gestor de Soporte > Departamentos > Añadir Departamento';
$lang['AdminDepartments.edit.page_title'] = 'Gestor de Soporte > Departamentos > Editar Departamento';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Añadir departamento';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Departamentos';
$lang['AdminDepartments.index.heading_name'] = 'Nombre';
$lang['AdminDepartments.index.heading_description'] = 'Descripción';
$lang['AdminDepartments.index.heading_email'] = 'Correo electrónico';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Personal asignado';
$lang['AdminDepartments.index.heading_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.index.heading_options'] = 'Opciones';
$lang['AdminDepartments.index.option_edit'] = 'Editar';
$lang['AdminDepartments.index.option_delete'] = 'Borrar';
$lang['AdminDepartments.index.confirm_delete'] = 'Los departamentos con tickets asignados no se pueden eliminar hasta que todos los tickets se hayan reasignado a un departamento alternativo. ¿Está seguro de que desea eliminar este departamento?';
$lang['AdminDepartments.index.no_results'] = 'No hay departamentos.';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Personal asignado';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personal';
$lang['AdminDepartments.assigned_staff.no_results'] = 'No hay personal asignado a este departamento.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Establezca la ruta de pipe como se muestra, pero asegúrese de utilizar la ruta correcta a PHP en su servidor. Asegúrese de que pipe.php es ejecutable. También puede ser necesario editar pipe.php para incluir un hashbang en la línea 1 que se vería algo como: #!/usr/bin/php';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Todos los tickets con un estado distinto de %1$s cuya última respuesta sea de un miembro del personal se cerrarán automáticamente si no se ha producido ninguna respuesta en el periodo de tiempo seleccionado.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Todos los tickets con un estado de %1$s se eliminarán automáticamente después de permanecer en ese estado durante el tiempo seleccionado.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Para todas las entradas con un estado distinto de %1$s, se enviará un recordatorio a la otra parte si no se ha respondido en el plazo seleccionado.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Al desmarcar esta casilla se indica que los nuevos tickets creados para este departamento (por correo electrónico o cliente) no enviarán un aviso de respuesta al cliente o al personal a través del correo electrónico Ticket Recibido o el correo electrónico Ticket Actualizado del Personal, respectivamente.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Cambia el estado a %1$s cuando responde un miembro del personal.';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Los servidores de correo tienen limitaciones en cuanto al tamaño de los archivos adjuntos y los tipos de archivo. Para mitigar el riesgo de que el correo electrónico sea rechazado, incluya las limitaciones de tipo y tamaño de los archivos adjuntos. Para asegurarse de que el cliente conoce los archivos adjuntos que no se han incluido, utilice la etiqueta {ticket.reply_has_attachments} en las notificaciones de los tickets.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista de extensiones admitidas separadas por comas (por ejemplo, zip,jpg,png).';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Tamaño máximo del adjunto a incluir en MB.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Si el cliente puede o no enviar el campo, si es false el cliente solo podrá leer el campo.';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Si se cierra el ticket, los datos del campo se borrarán automáticamente. Los datos dejarán de ser visibles para el personal.';
$lang['AdminDepartments.!text.add_response'] = 'Establecer una respuesta predefinida de cierre automático';
$lang['AdminDepartments.!text.no_selected_response'] = 'No se ha seleccionado la respuesta de cierre automático.';
$lang['AdminDepartments.!text.remove_response'] = 'Eliminar';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Añadir departamento';
$lang['AdminDepartments.add.tab_general'] = 'General';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.add.field_name'] = 'Nombre';
$lang['AdminDepartments.add.field_description'] = 'Descripción';
$lang['AdminDepartments.add.field_clients_only'] = 'Permitir sólo a los clientes abrir o responder tickets';
$lang['AdminDepartments.add.field_require_captcha'] = 'Requerir verificación humana para usuarios no autenticados';
$lang['AdminDepartments.add.field_email'] = 'Correo electrónico';
$lang['AdminDepartments.add.field_override_from_email'] = 'Sustituya la dirección de remitente establecida en las plantillas de correo electrónico por la dirección de correo electrónico establecida para este departamento.';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Enviar correos electrónicos de respuesta automática para nuevos tickets';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Transición automática del estado del ticket al responder el administrador';
$lang['AdminDepartments.add.field_method'] = 'Gestión del correo electrónico';
$lang['AdminDepartments.add.field_piping_config'] = 'Configuración de tuberías';
$lang['AdminDepartments.add.field_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.add.field_include_attachments'] = 'Incluir archivos adjuntos compatibles en las notificaciones de tickets';
$lang['AdminDepartments.add.field_attachment_types'] = 'Tipos de archivos adjuntos admitidos';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Tamaño máximo del accesorio';
$lang['AdminDepartments.add.field_security'] = 'Seguridad';
$lang['AdminDepartments.add.field_box_name'] = 'Nombre de la caja';
$lang['AdminDepartments.add.field_mark_messages'] = 'Marcar mensajes como';
$lang['AdminDepartments.add.field_host'] = 'Anfitrión';
$lang['AdminDepartments.add.field_user'] = 'Usuario';
$lang['AdminDepartments.add.field_pass'] = 'Pase';
$lang['AdminDepartments.add.field_port'] = 'Puerto';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Cerrar tickets automáticamente';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Borrar tickets automáticamente';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Envío automático de recordatorios de entradas';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Enviar recordatorios a los tickets con estado';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Enviar recordatorios a los tickets con prioridad';
$lang['AdminDepartments.add.field_response_id'] = 'Auto-cerrar Ticket Respuesta';
$lang['AdminDepartments.add.field_status'] = 'Estado';
$lang['AdminDepartments.add.field_addsubmit'] = 'Añadir departamento';
$lang['AdminDepartments.add.field_add_field'] = 'Añadir campo';
$lang['AdminDepartments.add.heading_label'] = 'Etiqueta';
$lang['AdminDepartments.add.heading_description'] = 'Descripción';
$lang['AdminDepartments.add.heading_visibility'] = 'Visibilidad';
$lang['AdminDepartments.add.heading_type'] = 'Tipo';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_step'] = 'Paso';
$lang['AdminDepartments.add.heading_client_add'] = 'El cliente puede Añadir';
$lang['AdminDepartments.add.heading_encrypted'] = 'Cifrado';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Borrado automático';
$lang['AdminDepartments.add.heading_options'] = 'Opciones';
$lang['AdminDepartments.add.heading_name'] = 'Nombre';
$lang['AdminDepartments.add.heading_value'] = 'Valor';
$lang['AdminDepartments.add.heading_default'] = 'Por defecto';
$lang['AdminDepartments.add.text_delete'] = 'Borrar';
$lang['AdminDepartments.add.text_add'] = 'Añadir';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Editar Departamento';
$lang['AdminDepartments.edit.tab_general'] = 'General';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Campos personalizados';
$lang['AdminDepartments.edit.field_name'] = 'Nombre';
$lang['AdminDepartments.edit.field_description'] = 'Descripción';
$lang['AdminDepartments.edit.field_clients_only'] = 'Permitir sólo a los clientes abrir o responder tickets';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Requerir verificación humana para usuarios no autenticados';
$lang['AdminDepartments.edit.field_email'] = 'Correo electrónico';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Sustituya la dirección de remitente establecida en las plantillas de correo electrónico por la dirección de correo electrónico establecida para este departamento.';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Enviar correos electrónicos de respuesta automática para nuevos tickets';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Transición automática del estado del ticket al responder el administrador';
$lang['AdminDepartments.edit.field_method'] = 'Gestión del correo electrónico';
$lang['AdminDepartments.edit.field_piping_config'] = 'Configuración de tuberías';
$lang['AdminDepartments.edit.field_default_priority'] = 'Prioridad por defecto';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Incluir archivos adjuntos compatibles en las notificaciones de tickets';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Tipos de archivos adjuntos admitidos';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Tamaño máximo del accesorio';
$lang['AdminDepartments.edit.field_security'] = 'Seguridad';
$lang['AdminDepartments.edit.field_box_name'] = 'Nombre de la caja';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Marcar mensajes como';
$lang['AdminDepartments.edit.field_host'] = 'Anfitrión';
$lang['AdminDepartments.edit.field_user'] = 'Usuario';
$lang['AdminDepartments.edit.field_pass'] = 'Pase';
$lang['AdminDepartments.edit.field_port'] = 'Puerto';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Cerrar tickets automáticamente';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Borrar tickets automáticamente';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Envío automático de recordatorios de entradas';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Enviar recordatorios a los tickets con estado';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Enviar recordatorios a los tickets con prioridad';
$lang['AdminDepartments.edit.field_response_id'] = 'Auto-cerrar Ticket Respuesta';
$lang['AdminDepartments.edit.field_status'] = 'Estado';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Editar Departamento';
$lang['AdminDepartments.edit.field_add_field'] = 'Añadir campo';
$lang['AdminDepartments.edit.confirm_field_remove'] = '¿Está seguro de que desea eliminar este campo personalizado? Se eliminarán todos los datos asociados a este campo. Si desea ocultar este campo y conservar los datos, cambie su Visibilidad a Solo personal.';
$lang['AdminDepartments.edit.no_results'] = 'No hay campos personalizados en este departamento.';
$lang['AdminDepartments.edit.heading_label'] = 'Etiqueta';
$lang['AdminDepartments.edit.heading_description'] = 'Descripción';
$lang['AdminDepartments.edit.heading_visibility'] = 'Visibilidad';
$lang['AdminDepartments.edit.heading_type'] = 'Tipo';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_step'] = 'Paso';
$lang['AdminDepartments.edit.heading_client_add'] = 'El cliente puede Añadir';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Cifrado';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Borrado automático';
$lang['AdminDepartments.edit.heading_options'] = 'Opciones';
$lang['AdminDepartments.edit.heading_name'] = 'Nombre';
$lang['AdminDepartments.edit.heading_value'] = 'Valor';
$lang['AdminDepartments.edit.heading_default'] = 'Por defecto';
$lang['AdminDepartments.edit.text_delete'] = 'Borrar';
$lang['AdminDepartments.edit.text_add'] = 'Añadir';
$lang['AdminDepartments.edit.field_priorities'] = 'Prioridades disponibles';
$lang['AdminDepartments.add.field_priorities'] = 'Prioridades disponibles';
$lang['AdminDepartments.edit.field_force_import'] = 'Importación forzosa';
$lang['AdminDepartments.add.field_force_import'] = 'Importación forzosa';
$lang['AdminDepartments.!success.department_imported'] = 'El departamento %1$s se ha importado correctamente.';
